/** Import an XLSX file.  **/

PROC IMPORT DATAFILE="/folders/myfolders/testgj.xls"
		    OUT=WORK.MYEXCEL
		    DBMS=XLS
		    REPLACE;
RUN;

/** Print the results. **/


ods noproctitle;

/*** Analyze numeric variables ***/
title "Descriptive Statistics for Numeric Variables";

proc means data=WORK.MYEXCEL n nmiss min mean median max std;
	var SYS1TO8 COUNTRY potatofriedp;
run;

title;

proc univariate data=WORK.MYEXCEL noprint;
	histogram SYS1TO8 COUNTRY potatofriedp;
run;


ods graphics / reset width=6.4in height=4.8in imagemap;

proc sgplot data=WORK.MYEXCEL;
	scatter x=COUNTRY y=potatofriedp /;
	xaxis grid;
	yaxis grid;
run;

ods graphics / reset;

Title;
ods noproctitle;
ods graphics / imagemap=on;

proc glm data=WORK.MYEXCEL;
	class COUNTRY;
	model potatofriedp=COUNTRY;
	means COUNTRY / hovtest=levene welch plots=none;
	lsmeans COUNTRY / adjust=tukey pdiff alpha=.05;
	run;
quit;


ods noproctitle;
ods graphics / imagemap=on;

/* Test for normality */
proc univariate data=WORK.MYEXCEL normal mu0=0;
	ods select TestsForNormality;
	class COUNTRY;
	var potatofriedp;
run;

/* t test */
proc ttest data=WORK.MYEXCEL sides=2 h0=0 plots(showh0);
	class COUNTRY;
	var potatofriedp;
run;

ods noproctitle;
ods graphics / imagemap=on;

proc glmselect data=WORK.MYEXCEL outdesign(addinputvars)=Work.reg_design;
	class COUNTRY / param=glm;
	model potatofriedp=SYS1TO8 COUNTRY / showpvalues selection=none;
run;

proc reg data=Work.reg_design alpha=0.05 plots(only)=(diagnostics residuals 
		observedbypredicted);
	where COUNTRY is not missing;
	ods select ParameterEstimates SpecTest ACovEst DiagnosticsPanel ResidualPlot 
		ObservedByPredicted;
	model potatofriedp=&_GLSMOD / spec acov;
	run;
quit;

proc delete data=Work.reg_design;
run;